import { Immutable } from "immer";
import { IActions, IActionsObj, IAsyncActions, IAsyncActionsObj, IAsyncProduce, IHooks, IHooksObj, IProduce, IUseStore } from "./common";
import { IPersistenceOptions } from "./plugins/persistenceStorage";
/**
 *  Create **react-state-selector** global store
 */
export declare function createStore<TStore, THooks extends IHooks<TStore>, TActions extends IActions<TStore>, TAsyncActions extends IAsyncActions<TStore>>(initialStore: Immutable<TStore>, options?: {
    /**
     * Custom hooks.
     */
    hooks?: THooks;
    /**
     * Custom actions.
     */
    actions?: TActions;
    /**
     * Custom async actions.
     */
    asyncActions?: TAsyncActions;
    /**
     * Name used to activate Redux DevTools.
     */
    devName?: string;
    /**
     * Flag to manually activate the usage of the Redux DevTools in production.
     */
    devToolsInProduction?: boolean;
    /**
     * Storage persistence for the store.
     * By default uses window.localStorage
     */
    storagePersistence?: IPersistenceOptions;
}): {
    /**
     * useStore: default hook that listens for any change in the store.
     */
    useStore: IUseStore<TStore>;
    /**
     * direct function to mutate the store
     */
    produce: IProduce<TStore>;
    /**
     * Async version of produce
     */
    asyncProduce: IAsyncProduce<TStore>;
    /**
     * Object containing the custom hooks specified in the options
     */
    hooks: IHooksObj<TStore, typeof options>;
    /**
     * Object containing the custom actions specified in the options
     */
    actions: IActionsObj<TStore, typeof options>;
    /**
     * Object containing the custom actions specified in the options
     */
    asyncActions: IAsyncActionsObj<TStore, typeof options>;
    /**
     * Promise that resolves when the store is ready to be used.
     * Only useful when using an Async Storage Persistance, like AsyncStorage from React Native
     */
    isReady: Promise<void>;
};
